@@ -47,29 +47,22 @@
 # univariateModels(cached statistics for the univariate indepence test), hash(hash booleab), stat_hash(hash object), 
 # example: test(target, data, xIndex, csIndex, univariateModels=NULL, hash=FALSE, stat_hash=NULL, pvalue_hash=NULL)
 # output of each test: LIST of the generated pvalue, stat and the updated hash objects.
-MMPC = function(target, dataset, max_k = 3, threshold = 0.05, test = NULL, ini = NULL, wei = NULL, user_test = NULL, 
+MMPC <- function(target, dataset, max_k = 3, threshold = 0.05, test = NULL, ini = NULL, wei = NULL, user_test = NULL, 
                 hash = FALSE, hashObject = NULL, ncores = 1, backward = FALSE) {
   ##############################
   # initialization part of MMPC 
   #############################
-  stat_hash = NULL;
-  pvalue_hash = NULL;
+  stat_hash <- NULL;
+  pvalue_hash <- NULL;
   
-  if( hash )  {
-    if ( requireNamespace("hash") )  {
-      if ( is.null(hashObject) )  {
-        stat_hash = hash();
-        pvalue_hash = hash();
-      } else if(class(hashObject) == "list"){
-        stat_hash = hashObject$stat_hash;
-        pvalue_hash = hashObject$pvalue_hash;
-      } else {
-        stop('hashObject must be a list of two hash objects (stat_hash, pvalue_hash)')
-      }
-    } else {
-      cat('The hash version of MMPC requires the hash package');
-      return(NULL);
-    }
+  if ( hash )  {
+    if (is.null(hashObject) )  {
+      stat_hash <- Rfast::Hash();
+      pvalue_hash <- Rfast::Hash();
+    } else if ( class(hashObject) == "list" ) {
+      stat_hash <- hashObject$stat_hash;
+      pvalue_hash <- hashObject$pvalue_hash;
+    } else   stop('hashObject must be a list of two hash objects (stat_hash, pvalue_hash)')
   }
   ###################################
   # dataset checking and initialize #
@@ -94,7 +87,7 @@ MMPC = function(target, dataset, max_k = 3, threshold = 0.05, test = NULL, ini =
   }
   if( is.null(dataset) || is.null(target) ) {  #|| (dim(as.matrix(target))[2] != 1 & class(target) != "Surv" ))
     stop('invalid dataset or target (class feature) arguments.');
-  } else  target = target;
+  } else  target <- target;
   #check for NA values in the dataset and replace them with the variable median or the mode
   if ( any(is.na(dataset)) ) {
     #dataset = as.matrix(dataset);
@@ -117,7 +110,7 @@ MMPC = function(target, dataset, max_k = 3, threshold = 0.05, test = NULL, ini =
   ##################################
   # target checking and initialize #
   ##################################
-  targetID = -1;
+  targetID <-  -1;
   #check if the target is a string
   if (is.character(target) & length(target) == 1) {
     findingTarget <- target == colnames(dataset);#findingTarget <- target %in% colnames(dataset);
