@@ -54,27 +54,22 @@
 # target(target variable), data(dataset), xIndex(x index), csIndex(cs index),  
 # univariateModels(cached statistics for the univariate indepence test), hash(hash booleab), stat_hash(hash object), 
 # output of each test: LIST of the generated pvalue, stat, flag and the updated hash objects.
-SES = function(target, dataset, max_k = 3, threshold = 0.05 , test = NULL, ini = NULL, wei = NULL, user_test = NULL, 
+SES <- function(target, dataset, max_k = 3, threshold = 0.05 , test = NULL, ini = NULL, wei = NULL, user_test = NULL, 
                hash = FALSE, hashObject = NULL, ncores = 1, backward = FALSE) {
   ##############################
   # initialization part of SES #
   ##############################
-  stat_hash = NULL;
-  pvalue_hash = NULL;
+  stat_hash <- NULL;
+  pvalue_hash <- NULL;
   
   if ( hash )  {
-    if ( requireNamespace("hash") )  {
-      if (is.null(hashObject) )  {
-        stat_hash = hash();
-        pvalue_hash = hash();
-      } else if ( class(hashObject) == "list" ) {
-        stat_hash = hashObject$stat_hash;
-        pvalue_hash = hashObject$pvalue_hash;
-      } else   stop('hashObject must be a list of two hash objects (stat_hash, pvalue_hash)')
-    } else {
-      cat('The hash version of SES requires the hash package');
-      return(NULL);
-    }
+    if (is.null(hashObject) )  {
+      stat_hash <- Rfast::Hash();
+      pvalue_hash <- Rfast::Hash();
+    } else if ( class(hashObject) == "list" ) {
+      stat_hash <- hashObject$stat_hash;
+      pvalue_hash <- hashObject$pvalue_hash;
+    } else   stop('hashObject must be a list of two hash objects (stat_hash, pvalue_hash)')
   }
   ###################################
   # dataset checking and initialize #
@@ -86,7 +81,7 @@ SES = function(target, dataset, max_k = 3, threshold = 0.05 , test = NULL, ini =
   }
   if ( is.null(dataset) || is.null(target) ) {  #|| (dim(as.matrix(target))[2] != 1 & class(target) != "Surv" ))
     stop('invalid dataset or target (class feature) arguments.');
-  } else  target = target;
+  } else  target <- target;
   #check for NA values in the dataset and replace them with the variable median or the mode
   if ( any(is.na(dataset) ) ) {
     #dataset = as.matrix(dataset);
@@ -109,7 +104,7 @@ SES = function(target, dataset, max_k = 3, threshold = 0.05 , test = NULL, ini =
   ##################################
   # target checking and initialize #
   ##################################
-  targetID = -1;
+  targetID <-  -1;
   #check if the target is a string
   if ( is.character(target) & length(target) == 1 ) {
     findingTarget <- target == colnames(dataset);#findingTarget <- target %in% colnames(dataset);
@@ -297,7 +292,7 @@ SES = function(target, dataset, max_k = 3, threshold = 0.05 , test = NULL, ini =
     bc <- mmpcbackphase(target, dataset[, varsToIterate, drop = FALSE], test = test, wei = wei, max_k = max_k, threshold = threshold)
     met <- bc$met
     results$selectedVars <- varsOrder[met]
-    results$selectedVarsOrder = varsOrder[met]
+    results$selectedVarsOrder <- varsOrder[met]
     results$signatures <- results$signatures[, met, drop = FALSE]
     results$pvalues[varsToIterate] <- bc$pvalue
     results$n.tests <- results$n.tests + bc$counter
