@@ -4,25 +4,28 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
     models <- univregs(target = target, dataset = dataset, test = test, wei = wei, ncores = ncores)  
   } else {
   
-  models <- list();
+  if ( length(xIndex) > 0 ) {
+      
+  models <- list()
   dm <- dim(dataset)
   rows <- dm[1]
   cols <- dm[2]
   id <- NULL
-  id <- Rfast::check_data(dataset)
-  if ( sum(id > 0) )  dataset[, id] <- rnorm(rows * length(id) )
-
+  # id <- Rfast::check_data(dataset)
+  # if ( sum(id > 0) )  dataset[, id] <- rnorm(rows * length(id) )
+  
+  options(warn = -1)
   if ( identical(test, testIndBeta) ) {  ## Beta regression
     lik2 <- dof <- numeric( cols )
     fit1 <- beta.reg(target, dataset[, csIndex, drop = FALSE])
     lik1 <- fit1$loglik
     d1 <- length(fit1$be)
     for (i in xIndex) {
-      fit2 <- beta.reg(target, dataset[, c(csIndex, xIndex[i] ) ])$loglik
+      fit2 <- beta.reg(target, dataset[, c(csIndex, xIndex[i] ) ])
       lik2[i] <- fit2$loglik
       dof[i] <- length(fit2$be)
     }
-    models$stat <- 2 * lik2 - 2 *lik1
+    models$stat <- 2 * (lik2 - lik1)
     models$pvalue <- pchisq(stat, dof - d1, lower.tail = FALSE, log.p = TRUE)
     
   } else if ( identical(test, testIndMMReg) ) {  ## M (Robust) linear regression
@@ -53,7 +56,7 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
       models$pvalue <- pchisq(models$stat, mod[, 2] - d1, lower.tail = FALSE, log.p = TRUE)
     }   
     
-  } else if ( identical(test, testIndReg) ) {  ## Weighted linear regression
+  } else if ( identical(test, testIndReg) ) {  ## linear regression
     
     if ( ncores <= 1 | is.null(ncores) ) {
       stat <- pvalue <- numeric(cols)
@@ -63,7 +66,8 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
         fit2 <- lm( target ~., data = dataset[, c(csIndex, i)], weights = wei, y = FALSE, model = FALSE )
         tab <- anova(fit1, fit2)
         stat[i] <- tab[2, 5] 
-        df1 <- tab[2, 3]    ;   df2 <- tab[2, 1]
+        df1 <- tab[2, 3]    
+        df2 <- tab[2, 1]
         pvalue[i] <- pf( stat[i], df1, df2, lower.tail = FALSE, log.p = TRUE )
       }
       models$stat <- stat
@@ -77,7 +81,8 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
         ww <- lm( target ~., data = dataset[, c(csIndex, i)], weights = wei, y = FALSE, model = FALSE )
         tab <- anova( fit1, ww )
         stat <- tab[2, 5] 
-        df1 <- tab[2, 3]   ;  df2 = tab[2, 1]
+        df1 <- tab[2, 3]  
+        df2 = tab[2, 1]
         pval <- pf( stat, df1, df2, lower.tail = FALSE, log.p = TRUE )
         return( c(stat, pval) )
       }
@@ -93,11 +98,12 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
       fit1 <- lm( target ~., data = dataset[, csIndex, drop = FALSE], weights = wei, y = FALSE, model = FALSE )
       
       for ( i in xIndex ) {
-        fit2 = lm( target ~., data = dataset[, c(csIndex, i)], weights = wei, y = FALSE, model = FALSE )
-        tab = anova(fit1, fit2)
-        stat[i] = tab[2, 5] 
-        df1 = tab[2, 6]    ;   df2 = tab[2, 7]
-        pvalue[i] = pf( stat[i], df1, df2, lower.tail = FALSE, log.p = TRUE )
+        fit2 <- lm( target ~., data = dataset[, c(csIndex, i)], weights = wei, y = FALSE, model = FALSE )
+        tab <- anova(fit1, fit2)
+        stat[i] <- tab[2, 5] 
+        df1 <- tab[2, 6]   
+        df2 <- tab[2, 7]
+        pvalue[i] <- pf( stat[i], df1, df2, lower.tail = FALSE, log.p = TRUE )
       }
       
     } else {
@@ -109,7 +115,8 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
         ww <- lm( target ~., data = dataset[, c(csIndex, i)], weights = wei, y = FALSE, model = FALSE )
         tab <- anova( fit1, ww )
         stat <- tab[2, 5] 
-        df1 <- tab[2, 6]   ;  df2 = tab[2, 7]
+        df1 <- tab[2, 6]   
+        df2 <- tab[2, 7]
         pval <- pf( stat, df1, df2, lower.tail = FALSE, log.p = TRUE )
         return( c(stat, pval) )
       }
@@ -126,9 +133,8 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
     if ( ncores <= 1 | is.null(ncores) ) {
       lik2 <- dof <- numeric( cols )
       for ( i in xIndex ) {
-        mat <- model.matrix(target ~ dataset[, i] )
-        fit2 <- ordinal::clm.fit( target, mat, weights = wei )
-        lik2[i] <- as.numeric( fit2$logLik )
+        fit2 <- ordinal::clm( target ~., data = dataset[, c(csIndex, i)], weights = wei )
+        lik2[i] <- as.numeric( logLik(fit2) )
         dof[i] <- length( coef(fit2) ) - df1
       }
       models$stat <- 2 * (lik2 - lik1)
@@ -139,9 +145,8 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
       cl <- makePSOCKcluster(ncores)
       registerDoParallel(cl)
       mod <- foreach(i = xIndex, .combine = rbind, .packages = "ordinal") %dopar% {
-        mat <- model.matrix( target ~ dataset[, i] )
-        fit2 <- ordinal::clm.fit(target, mat, weights = wei)
-        lik2 <- as.numeric( fit2$logLik )
+        fit2 <- ordinal::clm( target ~., data = dataset[, c(csIndex, i)], weights = wei )
+        lik2[i] <- as.numeric( logLik(fit2) )
         return( c(lik2, length( coef(fit2) ) ) )
       } 
       stopCluster(cl)
@@ -152,17 +157,17 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
     
   } else if ( identical(test, testIndMultinom) ) {  ## multinomial regression
     
-    target = as.factor( as.numeric( target ) );
-    fit1 = nnet::multinom( target ~., data = dataset[, csIndex, drop = FALSE], trace = FALSE, weights = wei )
+    target = as.factor( as.numeric( target ) )
+    fit1 = nnet::multinom( target ~., data = dataset[, csIndex, drop = FALSE], weights = wei, trace = FALSE )
     lik1 = as.numeric( logLik(fit1) )
     d1 = length( coef(fit1) )
     
     if ( ncores <= 1 | is.null(ncores) ) {
       lik2 <- dof <- numeric( cols )
       for ( i in xIndex ) {
-        fit2 = nnet::multinom( target ~., data = dataset[, c(csIndex, i)], trace = FALSE, weights = wei )
+        fit2 = nnet::multinom( target ~., data = dataset[, c(csIndex, i)], weights = wei, trace = FALSE )
         lik2[i] = as.numeric( logLik(fit2) )
-        dof[i] = length( coef(fit2) ) - df1
+        dof[i] = length( coef(fit2) ) 
       }
       models$stat = 2 * (lik2 - lik1)
       models$pvalue = pchisq(models$stat, dof - d1, lower.tail = FALSE, log.p = TRUE)
@@ -171,7 +176,7 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
       cl <- makePSOCKcluster(ncores)
       registerDoParallel(cl)
       mod <- foreach(i = xIndex, .combine = rbind, .packages = "nnet") %dopar% {
-        fit2 = nnet::multinom( target ~., data = dataset[, c(csIndex, i)], weights = wei )
+        fit2 = nnet::multinom( target ~., data = dataset[, c(csIndex, i)], weights = wei, trace = FALSE )
         lik2 = as.numeric( logLik(fit2 ) )
         return( c(lik2, length( coef(fit2) ) ) )
         
@@ -194,7 +199,7 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
         dof[i] = length( fit2$coefficients ) 
       }
       models$stat = lik1 - lik2
-      models$pvalue = pchisq(stat, dof - d1, lower.tail = FALSE, log.p = TRUE)
+      models$pvalue = pchisq(models$stat, dof - d1, lower.tail = FALSE, log.p = TRUE)
       
     } else {
       cl <- makePSOCKcluster(ncores)
@@ -299,10 +304,11 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
     if ( ncores <= 1 | is.null(ncores) ) {
       fit1 = glm( target ~ ., data = dataset[, csIndex, drop = FALSE], family = quasibinomial(link = logit), weights = wei )
       for ( i in xIndex ) {
-        fit2 = glm( target ~., data = dataset[, c(csIndex, i)], family = quasibinomial(link = logit), weights = wei )
+        fit2 <- glm( target ~., data = dataset[, c(csIndex, i)], family = quasibinomial(link = logit), weights = wei )
         tab <- anova(fit1, fit2, test = "F")
-        stat[i] = tab[2, 5]
-        df1 = tab[2, 3]   ;   df2 <- tab[2, 1]
+        stat[i] <- tab[2, 5]
+        df1 <- tab[2, 3]   
+        df2 <- tab[2, 1]
         pvalue[i] <- pf(tab[2,5] ,df1,df2, lower.tail = FALSE, log.p = TRUE)
       }
       models$stat <- stat
@@ -311,12 +317,13 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
     } else {
       cl <- makePSOCKcluster(ncores)
       registerDoParallel(cl)
-      fit1 = glm( target ~ ., data = dataset[, csIndex, drop = FALSE], family = quasibinomial(link = logit), weights = wei )
+      fit1 <- glm( target ~ ., data = dataset[, csIndex, drop = FALSE], family = quasibinomial(link = logit), weights = wei )
       mod <- foreach(i = xIndex, .combine = rbind) %dopar% {
-        fit2 = glm( target ~., data = dataset[, c(csIndex, i)], family = quasibinomial(link = logit), weights = wei )
+        fit2 <- glm( target ~., data = dataset[, c(csIndex, i)], family = quasibinomial(link = logit), weights = wei )
         tab <- anova(fit1, fit2, test = "F")
-        stat = tab[2, 5]
-        df1 = tab[2, 3]   ;   df2 <- tab[2, 1]
+        stat <- tab[2, 5]
+        df1 <- tab[2, 3]   
+        df2 <- tab[2, 1]
         pvalue <- pf(tab[2, 5], df1, df2, lower.tail = FALSE, log.p = TRUE)
         return( c(stat, pvalue ) )
       }
@@ -331,10 +338,11 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
     
     if ( ncores <= 1 | is.null(ncores) ) {
       for ( i in xIndex ) {
-        fit2 = glm( target ~., data = dataset[, c(csIndex, i)], family = quasipoisson(link = log), weights = wei )
+        fit2 <- glm( target ~., data = dataset[, c(csIndex, i)], family = quasipoisson(link = log), weights = wei )
         tab <- anova(fit1, fit2, test = "F")
-        stat[i] = tab[2, 5]
-        df1 = tab[2, 3]   ;   df2 <- tab[2, 1]
+        stat[i] <- tab[2, 5]
+        df1 <- tab[2, 3]   
+        df2 <- tab[2, 1]
         pvalue[i] <- pf(tab[2,5] ,df1,df2, lower.tail = FALSE, log.p = TRUE)
       }
       models$stat <- stat
@@ -345,10 +353,11 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
       registerDoParallel(cl)
       fit1 <- glm( target ~ ., data = dataset[, csIndex, drop = FALSE], family = quasipoisson(link = log), weights = wei )
       mod <- foreach(i = xIndex, .combine = rbind) %dopar% {
-        fit2 = glm( target ~., data = dataset[, c(csIndex, i)], family = quasipoisson(link = log), weights = wei )
+        fit2 <- glm( target ~., data = dataset[, c(csIndex, i)], family = quasipoisson(link = log), weights = wei )
         tab <- anova(fit1, fit2, test = "F")
-        stat = tab[2, 5]
-        df1 = tab[2, 3]   ;   df2 <- tab[2, 1]
+        stat <- tab[2, 5]
+        df1 <- tab[2, 3]   
+        df2 <- tab[2, 1]
         pvalue <- pf(tab[2, 5], df1, df2, lower.tail = FALSE, log.p = TRUE)
         return( c(stat, pvalue ) )
       }
@@ -363,10 +372,11 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
     if ( ncores <= 1 | is.null(ncores) ) {
       stat <- pvalue <- numeric( cols )
       for ( i in xIndex ) {
-        fit2 = glm( target ~., data = dataset[, c(csIndex, i)], family = gaussian(link = log), weights = wei )
+        fit2 <- glm( target ~., data = dataset[, c(csIndex, i)], family = gaussian(link = log), weights = wei )
         tab <- anova(fit1, fit2, test = "F")
-        stat[i] = tab[2, 5]
-        df1 = tab[2, 3]   ;   df2 <- tab[2, 1]
+        stat[i] <- tab[2, 5]
+        df1 <- tab[2, 3]   
+        df2 <- tab[2, 1]
         pvalue[i] <- pf(tab[2,5] ,df1,df2, lower.tail = FALSE, log.p = TRUE)
       }
       models$stat <- stat
@@ -376,10 +386,11 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
       cl <- makePSOCKcluster(ncores)
       registerDoParallel(cl)
       mod <- foreach(i = xIndex, .combine = rbind) %dopar% {
-        fit2 = glm( target ~ dataset[, i], family = gaussian(link = log), weights = wei )
+        fit2 <- glm( target ~ dataset[, i], family = gaussian(link = log), weights = wei )
         tab <- anova(fit1, fit2, test = "F")
-        stat = tab[2, 5]
-        df1 = tab[2, 3]   ;   df2 <- tab[2, 1]
+        stat <- tab[2, 5]
+        df1 <- tab[2, 3]   
+        df2 <- tab[2, 1]
         pvalue <- pf(tab[2, 5], df1, df2, lower.tail = FALSE, log.p = TRUE)
         return( c(stat, pvalue ) )
       }
@@ -389,28 +400,30 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
     }
     
   } else if ( identical(test, testIndGamma)   ) {  ## Gamma regression
-    fit1 = glm(target ~ 1, family = Gamma(link = log), weights = wei)
+    fit1 = glm(target ~., data = dataset[, csIndex, drop = FALSE], family = Gamma(link = log), weights = wei)
 
     if ( ncores <= 1 | is.null(ncores) ) {
       stat <- pvalue <- numeric( cols )
       for ( i in xIndex ) {
-        fit2 = glm( target ~., data = dataset[, c(csIndex, i)], family = Gamma(link = log), weights = wei )
+        fit2 <- glm( target ~., data = dataset[, c(csIndex, i)], family = Gamma(link = log), weights = wei )
         tab <- anova(fit1, fit2, test = "F")
-        stat[i] = tab[2, 5]
-        df1 = tab[2, 3]   ;   df2 <- tab[2, 1]
+        stat[i] <- tab[2, 5]
+        df1 <- tab[2, 3]   
+        df2 <- tab[2, 1]
         pvalue[i] <- pf(tab[2,5] ,df1,df2, lower.tail = FALSE, log.p = TRUE)
       }
-      models$stat = stat
-      models$pvalue = pvalue
+      models$stat <- stat
+      models$pvalue <- pvalue
       
     } else {
       cl <- makePSOCKcluster(ncores)
       registerDoParallel(cl)
       mod <- foreach(i = xIndex, .combine = rbind) %dopar% {
-        fit2 = glm( target ~., data = dataset[, c(csIndex, i)], family = Gamma(link = log), weights = wei )
+        fit2 <- glm( target ~., data = dataset[, c(csIndex, i)], family = Gamma(link = log), weights = wei )
         tab <- anova(fit1, fit2, test = "F")
-        stat = tab[2, 5]
-        df1 = tab[2, 3]   ;   df2 <- tab[2, 1]
+        stat <- tab[2, 5]
+        df1 <- tab[2, 3] 
+        df2 <- tab[2, 1]
         pvalue <- pf(tab[2, 5], df1, df2, lower.tail = FALSE, log.p = TRUE)
         return( c(stat, pvalue ) )
       }
@@ -425,10 +438,11 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
     if ( ncores <= 1 | is.null(ncores) ) {
       stat <- pvalue <- numeric( cols )
       for ( i in xIndex ) {
-        fit2 = glm( target ~., data = dataset[, c(csIndex, i)], family = inverse.gaussian(link = log), weights = wei )
+        fit2 <- glm( target ~., data = dataset[, c(csIndex, i)], family = inverse.gaussian(link = log), weights = wei )
         tab <- anova(fit1, fit2, test = "F")
-        stat[i] = tab[2, 5]
-        df1 = tab[2, 3]   ;   df2 <- tab[2, 1]
+        stat[i] <- tab[2, 5]
+        df1 <- tab[2, 3] 
+        df2 <- tab[2, 1]
         pvalue[i] <- pf(tab[2,5] ,df1,df2, lower.tail = FALSE, log.p = TRUE)
       }
       models$stat = stat
@@ -438,11 +452,11 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
       cl <- makePSOCKcluster(ncores)
       registerDoParallel(cl)
       mod <- foreach(i = xIndex, .combine = rbind) %dopar% {
-        fit2 = glm( target ~., data = dataset[, c(csIndex, i)], family = inverse.gaussian(link = log), weights = wei )
-        fit2 = glm( target ~., data = dataset[, c(csIndex, i)], family = Gamma(link = log), weights = wei )
+        fit2 <- glm( target ~., data = dataset[, c(csIndex, i)], family = inverse.gaussian(link = log), weights = wei )
         tab <- anova(fit1, fit2, test = "F")
-        stat = tab[2, 5]
-        df1 = tab[2, 3]   ;   df2 <- tab[2, 1]
+        stat <- tab[2, 5]
+        df1 <- tab[2, 3] 
+        df2 <- tab[2, 1]
         pvalue <- pf(tab[2, 5], df1, df2, lower.tail = FALSE, log.p = TRUE)
         return( c(stat, pvalue ) )
       }
@@ -452,15 +466,23 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
     }
     
   } else if ( identical(test, testIndZIP) ) {  ## Zero-inflated Poisson regression
-    moda <- zip.regs(target, dataset, wei, logged = TRUE, ncores = ncores) 
-    stat = moda[, 1]
-    pvalue = moda[, 2]
+    lik2 <- dof <- numeric( cols )
+    fit1 <- zip.reg(target, dataset[, csIndex, drop = FALSE])
+    lik1 <- fit1$loglik
+    d1 <- length(fit1$be)
+    for (i in xIndex) {
+      fit2 <- zip.reg(target, dataset[, c(csIndex, xIndex[i] ) ])
+      lik2[i] <- fit2$loglik
+      dof[i] <- length(fit2$be)
+    }
+    models$stat <- 2 * (lik2 - lik1)
+    models$pvalue <- pchisq(stat, dof - d1, lower.tail = FALSE, log.p = TRUE)
     
   } else if ( identical(test, testIndRQ) ) {  ## Median (quantile) regression
     
     if ( ncores <= 1 | is.null(ncores) ) {
-      fit1 = quantreg::rq(target ~., data = dataset[, csIndex, drop = FALSE], weights = wei)
-      stat = pval = numeric(cols)
+      fit1 <- quantreg::rq(target ~., data = dataset[, csIndex, drop = FALSE], weights = wei)
+      stat <- pval <- numeric(cols)
       for ( i in xIndex ) {
         fit2 = quantreg::rq(target ~., data = dataset[, c(csIndex, i)], weights = wei )
         ww = anova(fit1, fit2, test = "rank")
@@ -502,7 +524,7 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
         dof[i] <- res[2, 3]
       }
       models$stat <- stat
-      models$pvalue = pchisq(stat, dof, lower.tail = FALSE, log.p = TRUE)
+      models$pvalue <- pchisq(stat, dof, lower.tail = FALSE, log.p = TRUE)
       
     } else {
       cl <- makePSOCKcluster(ncores)
@@ -514,15 +536,15 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
         return( c(res[2, 2], res[2, 3] ) )
       }
       stopCluster(cl)
-      models$stat = mod[, 1]
-      models$pvalue = pchisq(mod[, 1], mod[, 2], lower.tail = FALSE, log.p = TRUE)
+      models$stat <- mod[, 1]
+      models$pvalue <- pchisq(mod[, 1], mod[, 2], lower.tail = FALSE, log.p = TRUE)
     }
     
   } else if ( identical(test, censIndWR) ) {  ## Weibull regression
     
     if ( ncores <= 1 | is.null(ncores) ) {
       stat <- dof <- numeric(cols)
-      fit1 = survival::survreg( target ~., data = dataset[, csIndex, drop = FALSE], weights = wei )
+      fit1 <- survival::survreg( target ~., data = dataset[, csIndex, drop = FALSE], weights = wei )
       for ( i in xIndex ) {
         fit2 = survival::survreg( target ~., data = dataset[, c(csIndex, i)], weights = wei )
         res <- anova(fit1, fit2)
@@ -544,13 +566,13 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
         return( c( res[2, 6],res[2, 5] ) )
       }
       stopCluster(cl)
-      models$stat = mod[, 1]
-      models$pvalue = pchisq(models$stat, mod[, 2], lower.tail = FALSE, log.p = TRUE)
+      models$stat <- mod[, 1]
+      models$pvalue <- pchisq(models$stat, mod[, 2], lower.tail = FALSE, log.p = TRUE)
     }
     
   } else if ( identical(test, censIndER) ) {  ## Exponential regression
     if ( ncores <= 1 | is.null(ncores) ) {
-      fit1 = survival::survreg( target ~., data = dataset[, csIndex, drop = FALSE], dist = "exponential", weights = wei )
+      fit1 <- survival::survreg( target ~., data = dataset[, csIndex, drop = FALSE], dist = "exponential", weights = wei )
       stat <- dof <- numeric(cols)
       
       for ( i in xIndex ) {
@@ -608,7 +630,7 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
     
   } else if ( identical(test, testIndClogit) ) {  ## Conditional logistic regression
     subject <- target[, 2] #the patient id
-    case <- as.logical(target[, 1]);  ## case 
+    case <- as.logical(target[, 1])  ## case 
 
     if ( ncores <= 1 | is.null(ncores) ) {
       fit1 <- survival::clogit( case ~., data = dataset[, csIndex, drop = FALSE] + strata(subject) ) 
@@ -637,13 +659,15 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
     
   }  else   models <- NULL  ## end of all if (test == )
   
-  if ( !is.null(models) )  {
-    if ( sum(id>0) > 0 ) {
-      models$stat[id] = 0
-      models$pvalue[id] = log(1)
-    }
-  }
+  models$stat[ - xIndex ] <- 0
+  models$pvalue[ - xIndex ] <- log(1)
   
+  } else {
+    models <- list()
+    models$stat <- NULL
+    models$pvalue <- NULL
+  }  ##  end  if  ( length(xIndex) > 0 )  
+    
   }  ## end if ( identical(csIndex, 0) )
   
   models
