@@ -1,26 +1,19 @@
-wald.mmpc = function(target, dataset, max_k = 3, threshold = 0.05, test = NULL, ini = NULL, wei = NULL, user_test = NULL, 
+wald.mmpc <- function(target, dataset, max_k = 3, threshold = 0.05, test = NULL, ini = NULL, wei = NULL, user_test = NULL, 
                      hash=FALSE, hashObject=NULL, ncores = 1, backward = FALSE) {
   ##############################
   # initialization part of MMPC 
   #############################
-  stat_hash = NULL;
-  pvalue_hash = NULL;
+  stat_hash <- NULL
+  pvalue_hash <- NULL
   
-  if( hash )  {
-    if ( requireNamespace("hash") )  {
-      if ( is.null(hashObject) )  {
-        stat_hash = hash();
-        pvalue_hash = hash();
-      } else if(class(hashObject) == "list"){
-        stat_hash = hashObject$stat_hash;
-        pvalue_hash = hashObject$pvalue_hash;
-      } else {
-        stop('hashObject must be a list of two hash objects (stat_hash, pvalue_hash)')
-      }
-    } else {
-      cat('The hash version of MMPC requires the hash package');
-      return(NULL);
-    }
+  if ( hash )  {
+    if (is.null(hashObject) )  {
+      stat_hash <- Rfast::Hash();
+      pvalue_hash <- Rfast::Hash();
+    } else if ( class(hashObject) == "list" ) {
+      stat_hash <- hashObject$stat_hash;
+      pvalue_hash <- hashObject$pvalue_hash;
+    } else   stop('hashObject must be a list of two hash objects (stat_hash, pvalue_hash)')
   }
   ###################################
   # dataset checking and initialize #
@@ -40,7 +33,7 @@ wald.mmpc = function(target, dataset, max_k = 3, threshold = 0.05, test = NULL,
   ##################################
   # target checking and initialize #
   ##################################
-  targetID = -1;
+  targetID <-  -1;
   #check if the target is a string
   if (is.character(target) & length(target) == 1) {
     findingTarget <- target == colnames(dataset);#findingTarget <- target %in% colnames(dataset);
