@@ -1,23 +1,19 @@
-wald.ses = function(target, dataset, max_k = 3, threshold = 0.05, test = NULL, ini = NULL, wei = NULL, user_test = NULL, 
+wald.ses <- function(target, dataset, max_k = 3, threshold = 0.05, test = NULL, ini = NULL, wei = NULL, user_test = NULL, 
                     hash = FALSE, hashObject = NULL, ncores = 1, backward = FALSE) {
   ##############################
   # initialization part of SES #
   ##############################
-  stat_hash = NULL;
-  pvalue_hash = NULL;
+  stat_hash <- NULL
+  pvalue_hash <- NULL
+  
   if ( hash )  {
-    if ( requireNamespace("hash") )  {
-      if (is.null(hashObject) )  {
-        stat_hash = hash();
-        pvalue_hash = hash();
-      } else if ( class(hashObject) == "list" ) {
-        stat_hash = hashObject$stat_hash;
-        pvalue_hash = hashObject$pvalue_hash;
-      } else   stop('hashObject must be a list of two hash objects (stat_hash, pvalue_hash)')
-    } else {
-      cat('The hash version of SES requires the hash package');
-      return(NULL);
-    }
+    if (is.null(hashObject) )  {
+      stat_hash <- Rfast::Hash();
+      pvalue_hash <- Rfast::Hash();
+    } else if ( class(hashObject) == "list" ) {
+      stat_hash <- hashObject$stat_hash;
+      pvalue_hash <- hashObject$pvalue_hash;
+    } else   stop('hashObject must be a list of two hash objects (stat_hash, pvalue_hash)')
   }
   ###################################
   # dataset checking and initialize #
@@ -29,7 +25,7 @@ wald.ses = function(target, dataset, max_k = 3, threshold = 0.05, test = NULL, i
   }
   if( is.null(dataset) || is.null(target) ) {    #|| (dim(as.matrix(target))[2] != 1 & class(target) != "Surv" ))
     stop('invalid dataset or target (class feature) arguments.');
-  } else  target = target;
+  } else  target <- target;
     if ( any( is.na(dataset) ) ) {
     warning("The dataset contains missing values (NA) and they were replaced automatically by the variable (column) median (for numeric) or by the most frequent level (mode) if the variable is factor")
     dataset <- apply( dataset, 2, function(x){ x[which(is.na(x))] = median(x, na.rm = TRUE) ; return(x) } ) 
@@ -37,7 +33,7 @@ wald.ses = function(target, dataset, max_k = 3, threshold = 0.05, test = NULL, i
   ##################################
   # target checking and initialize #
   ##################################
-  targetID = -1;
+  targetID <-  -1;
   #check if the target is a string
   if (is.character(target) & length(target) == 1) {
     findingTarget <- target == colnames(dataset);#findingTarget <- target %in% colnames(dataset);
@@ -63,7 +59,7 @@ wald.ses = function(target, dataset, max_k = 3, threshold = 0.05, test = NULL, i
   la <- length( unique( as.numeric(target) ) )
   
   if(typeof(user_test) == "closure") {
-    test = user_test;
+    test <- user_test;
   } else {
     #auto detect independence test in case of not defined by the user and the test is null or auto
     if (is.null(test) || test == "auto") {
@@ -171,7 +167,7 @@ wald.ses = function(target, dataset, max_k = 3, threshold = 0.05, test = NULL, i
     bc <- mmpcbackphase(target, dataset[, varsToIterate, drop = FALSE], test = test, wei = wei, max_k = max_k, threshold = threshold)
     met <- bc$met
     results$selectedVars <- varsOrder[met]
-    results$selectedVarsOrder = varsOrder[met]
+    results$selectedVarsOrder <- varsOrder[met]
     results$signatures <- results$signatures[, met, drop = FALSE]
     results$pvalues[varsToIterate] <- bc$pvalue
     results$n.tests <- results$n.tests + bc$counter
